"""
Provides open_geodata version information.
"""

# This file is auto-generated! Do not edit!
# Use `python -m incremental.update open_geodata` to change this file.

from incremental import Version

__version__ = Version("open_geodata", 22, 6, 60)
__all__ = ["__version__"]
